#include <boost/program_options.hpp>
#include <iostream>

#include "Tachyon.h"

namespace po = boost::program_options;

int main(int argc, char *argv[])
{
   // Declare the supported options.
   po::options_description desc("Allowed options");
   desc.add_options()
       ("help,h", "produce help message")
       ("tachyon-name", po::value<std::string>(), "tachyon name")
       ("accelleration,a", po::value<double>(), "set time acceleration factor")
       ("time,t", po::value<time_t>(), "set time value in seconds")
   ;

   po::positional_options_description p;
   p.add("tachyon-name", -1);

   po::variables_map vm;
   po::store(po::command_line_parser(argc, argv).
             options(desc).positional(p).run(), vm);
   po::notify(vm);    

   if (vm.count("help"))
   {
       std::cout << desc << "\n";
       return 0;
   }

   if (vm.count("tachyon-name"))
   {
      std::string name;

      name =  vm["tachyon-name"].as<std::string>();
      Tachyon t(name.c_str());
      if (vm.count("accelleration"))
      {
         double factor =  vm["accelleration"].as<double>();
         t.accellerate(factor);
      }

      if (vm.count("time"))
      {
         time_t newtime = vm["time"].as<time_t>();
         t.settime(newtime);
      }
   }
   else
   {
      std::cerr << "Usage: tachyon [options] tachyon-name.\n";
      return 1;
   }

   return 0;
}


